package com.ruoyi.os.mapper;


import java.util.List;
import com.ruoyi.os.domain.HealthcareOsComplaints;
import org.apache.ibatis.annotations.Mapper;

/**
 * 主诉Mapper接口
 *
 * @author 何顺
 * @date 2024-09-24
 */
@Mapper
public interface HealthcareOsComplaintsMapper
{
    /**
     * 查询主诉
     *
     * @param id 主诉主键
     * @return 主诉
     */
    public HealthcareOsComplaints selectHealthcareOsComplaintsById(Long id);

    /**
     * 查询主诉列表
     *
     * @param healthcareOsComplaints 主诉
     * @return 主诉集合
     */
    public List<HealthcareOsComplaints> selectHealthcareOsComplaintsList(HealthcareOsComplaints healthcareOsComplaints);

    /**
     * 新增主诉
     *
     * @param healthcareOsComplaints 主诉
     * @return 结果
     */
    public int insertHealthcareOsComplaints(HealthcareOsComplaints healthcareOsComplaints);

    /**
     * 修改主诉
     *
     * @param healthcareOsComplaints 主诉
     * @return 结果
     */
    public int updateHealthcareOsComplaints(HealthcareOsComplaints healthcareOsComplaints);

    /**
     * 删除主诉
     *
     * @param id 主诉主键
     * @return 结果
     */
    public int deleteHealthcareOsComplaintsById(Long id);

    /**
     * 批量删除主诉
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthcareOsComplaintsByIds(Long[] ids);
}
